pub enum SpeechCommandClass {
Show 37 variants
Yes = 0,
No = 1,
Up = 2,
Down = 3,
Left = 4,
Right = 5,
On = 6,
Off = 7,
Stop = 8,
Go = 9,
Zero = 10,
One = 11,
Two = 12,
Three = 13,
Four = 14,
Five = 15,
Six = 16,
Seven = 17,
Eight = 18,
Nine = 19,
Bed = 20,
Bird = 21,
Cat = 22,
Dog = 23,
Happy = 24,
House = 25,
Marvin = 26,
Sheila = 27,
Tree = 28,
Wow = 29,
Backward = 30,
Forward = 31,
Follow = 32,
Learn = 33,
Visual = 34,
Silence = 35,
Other = 36,
}Available on crate features
std and dataset only.Expand description
Enum representing speech command classes in the Speech Commands dataset. Class names are based on the Speech Commands dataset from Huggingface. See speech_commands for more information.
Variants
Yes = 0
No = 1
Up = 2
Down = 3
Left = 4
Right = 5
On = 6
Off = 7
Stop = 8
Go = 9
Zero = 10
One = 11
Two = 12
Three = 13
Four = 14
Five = 15
Six = 16
Seven = 17
Eight = 18
Nine = 19
Bed = 20
Bird = 21
Cat = 22
Dog = 23
Happy = 24
House = 25
Marvin = 26
Sheila = 27
Tree = 28
Wow = 29
Backward = 30
Forward = 31
Follow = 32
Learn = 33
Visual = 34
Silence = 35
Other = 36
Implementations