Mapper

Trait Mapper 

pub trait Mapper<I, O>: Send + Sync {
    // Required method
    fn map(&self, item: &I) -> O;
}
Available on crate features dataset and std only.
Basic mapper trait to be used with the mapper dataset.

Required Methods

fn map(&self, item: &I) -> O

Maps an item of type I to an item of type O.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors