pub struct SegmentationMask {
pub mask: Vec<usize>,
}Available on crate features
std and dataset only.Expand description
Segmentation mask annotation. For semantic segmentation, a mask has a single channel (C = 1). For instance segmentation, there may be multiple masks per image (C >= 1).
Fields
mask: Vec<usize>Segmentation mask.