pub struct LoraConfig {
pub rank: usize,
pub alpha: f64,
pub init_std: Option<f64>,
pub param_group: ParamGroup,
}Expand description
Configuration describing how to attach LoRA adapters to a module’s weights.
Fields
rank: usizeRank of the low-rank decomposition.
alpha: f64Scaling numerator; the adapter contribution is scaled by alpha / rank.
init_std: Option<f64>Standard deviation used to initialize the A factor. Defaults to 1 / rank.
param_group: ParamGroupThe parameter group on which to apply the LoRA.
Implementations
Sourceimpl LoraConfig
impl LoraConfig
Sourcepub fn new(rank: usize, alpha: f64) -> Self
pub fn new(rank: usize, alpha: f64) -> Self
Create a new LoRA configuration with the given rank and alpha.
Sourcepub fn set_param_group(self, group: ParamGroup) -> Self
pub fn set_param_group(self, group: ParamGroup) -> Self
Set the parameter group to quantize on which to apply the LoRA.