pub struct ParamGroup { /* private fields */ }Expand description
A way to represent a group of parameter for a Burn module.
Implementations
Sourceimpl ParamGroup
impl ParamGroup
Sourcepub fn matches(&self, id: &ParamId, path: Option<&str>) -> bool
pub fn matches(&self, id: &ParamId, path: Option<&str>) -> bool
Evaluates whether a given parameter ID and its module path match this group.
Sourcepub fn ids_from_module<M: Module>(module: M) -> Self
pub fn ids_from_module<M: Module>(module: M) -> Self
Returns a parameter group with all of the module’s parameters.
Sourcepub fn from_path(path: impl Into<String>) -> Self
pub fn from_path(path: impl Into<String>) -> Self
Matches parameters by exact text path (e.g., “model.backbone.linear.weight”)
Sourcepub fn from_paths(paths: Vec<impl Into<String>>) -> Self
pub fn from_paths(paths: Vec<impl Into<String>>) -> Self
Matches parameters by exact text paths (e.g., “model.backbone.linear.weight”, etc.)
Sourcepub fn from_predicate(path: impl Into<String>) -> Self
pub fn from_predicate(path: impl Into<String>) -> Self
Matches parameters that include the predicate in their paths (e.g., “backbone”)
Sourcepub fn from_predicates(paths: Vec<impl Into<String>>) -> Self
pub fn from_predicates(paths: Vec<impl Into<String>>) -> Self
Matches parameters that include all the predicates in their path (AND logic). (e.g., parameter path contains “backbone” and “linear”)
Sourcepub fn from_any_predicates(paths: Vec<impl Into<String>>) -> Self
pub fn from_any_predicates(paths: Vec<impl Into<String>>) -> Self
Matches parameters that include any of the predicates in their path (OR logic). (e.g., parameter path contains “backbone” or “linear”)
Sourcepub fn from_regex<S: AsRef<str>>(pattern: S) -> Result<Self, ParamGroupError>
Available on crate feature std only.
pub fn from_regex<S: AsRef<str>>(pattern: S) -> Result<Self, ParamGroupError>
std only.Matches parameters by regex pattern (e.g., “^model.layer.\d+$”)
Errors
Returns a ParamGroupError::InvalidPatternError if the string cannot be compiled into a valid regex.
Sourcepub fn from_regexes<S: AsRef<str>>(
patterns: Vec<S>,
) -> Result<Self, ParamGroupError>
Available on crate feature std only.
pub fn from_regexes<S: AsRef<str>>( patterns: Vec<S>, ) -> Result<Self, ParamGroupError>
std only.Matches parameters for all the regex patterns (AND logic). (e.g., “^encoder.layer.\d+”, and “bias$” )
Errors
Returns a ParamGroupError::InvalidPatternError if the strings cannot be compiled into a valid regex.
Sourcepub fn from_any_regexes<S: AsRef<str>>(
patterns: Vec<S>,
) -> Result<Self, ParamGroupError>
Available on crate feature std only.
pub fn from_any_regexes<S: AsRef<str>>( patterns: Vec<S>, ) -> Result<Self, ParamGroupError>
std only.Matches parameters for any the regex patterns (OR logic). (e.g., “^encoder.layer.\d+$”, or “^decoder.layer.\d+$” )
Errors
Returns a ParamGroupError::InvalidPatternError if the strings cannot be compiled into a valid regex.