RunningState

Struct RunningState 

pub struct RunningState<V> { /* private fields */ }
A state that can be updated during the forward pass while being thread safe.

Note

The state value is the average of all updates on all threads.

Implementations

Source

impl<const D: usize> RunningState<Tensor<D>>

pub fn new(value: Tensor<D>) -> Self

Create a new running state.

pub fn with_id(id: ParamId, value: Tensor<D>) -> Self

Create a new running state.

pub fn from_record(record: Param<Tensor<D>>) -> Self

Create a new running state from a record.

pub fn update(&self, value: Tensor<D>)

Update the value on the current thread.

pub fn value(&self) -> Tensor<D>

Get the current value,

Note

The current value might be outdated by one update.

pub fn value_sync(&self) -> Tensor<D>

Get the current value and make sure it is sync.

Note

Don’t use this function after an update on the same thread where other threads might have to register their update before the actual synchronization needs to happen.