pub struct TransformerDecoderConfig {
pub d_model: usize,
pub d_ff: usize,
pub n_heads: usize,
pub n_layers: usize,
pub dropout: f64,
pub norm_first: bool,
pub quiet_softmax: bool,
pub initializer: Initializer,
}Expand description
Configuration to create a Transformer Decoder layer using the init function.
Fields
d_model: usizeThe size of the model.
d_ff: usizeThe size of the position-wise feed-forward network.
n_heads: usizeThe number of attention heads.
n_layers: usizeThe number of layers.
dropout: f64The dropout rate. Default: 0.1
norm_first: boolLayer norm will be applied first instead of after the other modules.
quiet_softmax: boolUse “quiet softmax” instead of regular softmax.
- Usage may improve performance by allowing attention heads to deposit no information (if the sequence contains no information relevant to that head).
- Usage may reduce the entropy of weights in the model, enhancing quantization and compression.
Reference: https://www.evanmiller.org/attention-is-off-by-one.html
initializer: InitializerThe type of function used to initialize neural network parameters
Implementations
Sourceimpl TransformerDecoderConfig
impl TransformerDecoderConfig
Sourcepub fn with_dropout(self, dropout: f64) -> Self
pub fn with_dropout(self, dropout: f64) -> Self
The dropout rate. Default: 0.1
Sourcepub fn with_norm_first(self, norm_first: bool) -> Self
pub fn with_norm_first(self, norm_first: bool) -> Self
Layer norm will be applied first instead of after the other modules.
Sourcepub fn with_quiet_softmax(self, quiet_softmax: bool) -> Self
pub fn with_quiet_softmax(self, quiet_softmax: bool) -> Self
Use “quiet softmax” instead of regular softmax.
Sourcepub fn with_initializer(self, initializer: Initializer) -> Self
pub fn with_initializer(self, initializer: Initializer) -> Self
The type of function used to initialize neural network parameters
Sourceimpl TransformerDecoderConfig
impl TransformerDecoderConfig
Sourcepub fn init<B: Backend>(&self, device: &B::Device) -> TransformerDecoder<B>
pub fn init<B: Backend>(&self, device: &B::Device) -> TransformerDecoder<B>
Initialize a new Transformer Decoder module.