pub trait FileRecorder<B: Backend>: Recorder<B, RecordArgs = PathBuf, RecordOutput = (), LoadArgs = PathBuf> {
// Required method
fn file_extension() -> &'static str;
}Available on crate feature
std only.Expand description
Recorder trait specialized to save and load data to and from files.
Required Methods
Sourcefn file_extension() -> &'static str
fn file_extension() -> &'static str
File extension of the format used by the recorder.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".