pub struct TensorCreationOptions {
pub device: Device,
pub dtype: Option<DType>,
}Expand description
Options for tensor creation.
This struct allows specifying the device and overriding the data type when creating a tensor.
When the dtype is not specified, the device’s default settings is used.
Fields
device: DeviceDevice where the tensor will be created.
dtype: Option<DType>Optional data type.
If None, the dtype will be inferred on creation from the device settings.
Implementations
Sourceimpl TensorCreationOptions
impl TensorCreationOptions
Sourcepub fn new(device: Device) -> TensorCreationOptions
pub fn new(device: Device) -> TensorCreationOptions
Create new options with a specific device.
Data type will follow the device settings on tensor creation.
Sourcepub fn with_dtype(self, dtype: DType) -> TensorCreationOptions
pub fn with_dtype(self, dtype: DType) -> TensorCreationOptions
Set the tensor creation data type.
Sourcepub fn with_device(self, device: Device) -> TensorCreationOptions
pub fn with_device(self, device: Device) -> TensorCreationOptions
Set the tensor creation device.
Sourcepub fn dtype_or(&self, dtype: DType) -> DType
pub fn dtype_or(&self, dtype: DType) -> DType
Returns the tensor data type, or a provided default if not set.
This is useful for cases where TensorCreationOptions may not have an explicit dtype.