pub trait Element:
ToElement
+ ElementRandom
+ ElementConversion
+ ElementEq
+ CheckedBitPattern
+ NoUninit
+ Zeroable
+ Debug
+ Display
+ Default
+ Send
+ Sync
+ Copy
+ 'static {
// Required method
fn dtype() -> DType;
}Expand description
Core element trait for tensor values.
This trait defines the minimal set of capabilities required for a type to be stored and manipulated as a tensor element across all backends.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".