Module for the neural network module.
Macros
- empty
- Constant macro.
Structs
- Attribute
- Attribute to print in the display method.
- Content
- Struct to store the attributes of a module for formatting.
- Display
Settings - Custom module display settings.
- Empty
Record - A record representing the absence of persistent module state.
- Ignored
Deprecated - Container to satisfy the Module trait for types that are not modules.
- Param
- Parameters are the fundamental building blocks of modules where they serve as containers for tensors that can be updated during training, and loaded during inference. If you don’t want to save the tensors and/or don’t want to update it during training, you don’t need this type to wrap your tensor.
- ParamId
- Unique ID for a parameter of a module.
- Param
Mapper - Applies transformations when loading and saving parameters.
- Quantizer
- Describes how to quantize a module.
- Reinitializer
std - Overrides float and int tensors of burn modules.
- Running
State - A state that can be updated during the forward pass while being thread safe.
Enums
- Initializer
- Enum specifying with what values a tensor should be initialized
Traits
- Autodiff
Module - Module with auto-differentiation backend.
- HasAutodiff
Module - Helper trait to associate a module with its autodiff version.
- Module
- Trait for all neural network modules.
- Module
Display - Trait to implement custom display settings for a module.
- Module
Display Default - Default display settings for a module.
- Module
Mapper - Module mapper trait for transforming module parameters.
- Module
Visitor - Module visitor trait for traversing and inspecting module parameters.
- Parameter
- Trait that defines what is necessary for a type to be a parameter.
Functions
- extract_
type_ name - Extracts the short name of a type T
- list_
param_ ids - List all the parameter ids in a module.
Type Aliases
- Constant
Record Deprecated - A record representing the absence of persistent module state.
- Devices
- Type alias to
Vec<B::Device>which supportsno_stdenvironments, but automatically using thealloccrate.
Derive Macros
- Module
- Derive macro for the
Moduletrait.