pub struct RunningState<V> { /* private fields */ }Expand description
A state that can be updated during the forward pass while being thread safe.
Note
The state value is the average of all updates on all threads.
Implementations
Sourceimpl<const D: usize> RunningState<Tensor<D>>
impl<const D: usize> RunningState<Tensor<D>>
Sourcepub fn from_record(record: Param<Tensor<D>>) -> Self
pub fn from_record(record: Param<Tensor<D>>) -> Self
Create a new running state from a record.
Sourcepub fn value_sync(&self) -> Tensor<D>
pub fn value_sync(&self) -> Tensor<D>
Get the current value and make sure it is sync.
Note
Don’t use this function after an update on the same thread where other threads might have to register their update before the actual synchronization needs to happen.